@@ -124,6 +124,9 @@ static void file_changed (GnomeVFSMonitorHandle *handle,
 
 static void applet_destroy(GtkObject *widget)
 {
+	PersonalLauncher *plugin = PERSONAL_LAUNCHER(widget);
+	if (plugin->updateTimeout)
+		g_source_remove(plugin->updateTimeout);
 	gtk_object_destroy(widget);
 }
 
@@ -168,10 +171,10 @@ static gint applet_expose(GtkWidget *widget, GdkEventExpose *event)
 			&width,
 			&height);
 
-	if ((plugin->clip.x!=event->area.x - x_offset)||(plugin->clip.y!=event->area.y - y_offset)||(plugin->clip.width!=event->area.width)||(plugin->clip.height!=event->area.height))
+	if ((plugin->clip.x!=event->area.x - x_offset)||(plugin->clip.y!=event->area.y - y_offset)||(plugin->clip.width!=event->area.width + x_offset)||(plugin->clip.height!=event->area.height + y_offset))
 	{
 		if (!plugin->updateTimeout)
-			plugin->updateTimeout=g_timeout_add(1000,(GSourceFunc)launcher_changed,plugin);
+			plugin->updateTimeout=g_timeout_add(100,(GSourceFunc)launcher_changed,plugin);
 	}
 	
 	plugin->clip.x = event->area.x - x_offset;
